==> amity-sdk-6.47.0-sources.jar: main/com/amity/socialcloud/sdk/video/data/stream/StreamMediator.kt <==
package com.amity.socialcloud.sdk.video.data.stream

import androidx.paging.ExperimentalPagingApi
import co.amity.rxbridge.toRx2
import com.amity.socialcloud.sdk.dto.video.EkoStreamQueryDto
import com.amity.socialcloud.sdk.entity.video.stream.EkoStreamEntity
import com.amity.socialcloud.sdk.model.video.stream.AmityStream
import com.amity.socialcloud.sdk.video.domain.stream.StreamReactorUseCase
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.keycreator.StreamKeyCreator
import com.ekoapp.ekosdk.internal.mediator.DynamicQueryStreamMediator
import com.ekoapp.ekosdk.internal.token.DynamicQueryStreamQueryToken
import com.ekoapp.ekosdk.internal.token.QueryStreamQueryToken
import io.reactivex.Completable
import io.reactivex.Flowable
import io.reactivex.Single

@ExperimentalPagingApi
internal class StreamMediator(
    val statuses: List<String>
) : DynamicQueryStreamMediator<EkoStreamEntity, EkoStreamQueryDto, AmityStream>(
        nonce = AmityNonce.STREAM_LIST,
        dynamicQueryStreamKeyCreator = StreamKeyCreator(statuses),
) {
    
    override fun provideReactorPublisher(): Flowable<AmityStream> {
        return StreamReactorUseCase().execute(statuses).toRx2()
    }
    
    override fun forceRefresh(): Boolean = true
    
    override fun getFirstPageRequest(pageSize: Int): Single<EkoStreamQueryDto> {
        return getRequest(limit = pageSize)
    }
    
    override fun getFetchByTokenRequest(token: String): Single<EkoStreamQueryDto> {
        return getRequest(token = token)
    }
    
    override fun persistResponse(dto: EkoStreamQueryDto): Completable {
        return StreamListQueryPersister().persist(dto).toRx2()
    }
    
    override fun convertResponseToQueryToken(dto: EkoStreamQueryDto): QueryStreamQueryToken {
        return DynamicQueryStreamQueryToken(
                dynamicQueryStreamKeyCreator = StreamKeyCreator(statuses),
                next = dto.token.next,
                previous = dto.token?.previous,
                primaryKeys = dto.result.streams.map { post -> post.streamId }
        )
    }
    
    private fun getRequest(
            limit: Int? = null,
            token: String? = null
    ): Single<EkoStreamQueryDto> {
        return StreamRemoteDataStore().queryVideoStreaming(
            isLive = null,
            statuses = statuses,
            userPublicIds = null,
            sortBy = null,
            isDeleted = null,
            limit = limit,
            token = token
        ).toRx2()
    }
}

==> amity-sdk-7.12.8-sources.jar: main/com/amity/socialcloud/sdk/video/data/stream/StreamMediator.kt <==
package com.amity.socialcloud.sdk.video.data.stream

import androidx.paging.ExperimentalPagingApi
import co.amity.rxbridge.toRx2
import com.amity.socialcloud.sdk.dto.video.EkoStreamQueryDto
import com.amity.socialcloud.sdk.entity.video.stream.EkoStreamEntity
import com.amity.socialcloud.sdk.model.video.stream.AmityStream
import com.amity.socialcloud.sdk.video.domain.stream.StreamReactorUseCase
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.keycreator.StreamKeyCreator
import com.ekoapp.ekosdk.internal.mediator.DynamicQueryStreamMediator
import com.ekoapp.ekosdk.internal.token.DynamicQueryStreamQueryToken
import com.ekoapp.ekosdk.internal.token.QueryStreamQueryToken
import io.reactivex.Completable
import io.reactivex.Flowable
import io.reactivex.Single

@ExperimentalPagingApi
internal class StreamMediator(
    val statuses: List<String>
) : DynamicQueryStreamMediator<EkoStreamEntity, EkoStreamQueryDto, AmityStream>(
        nonce = AmityNonce.STREAM_LIST,
        dynamicQueryStreamKeyCreator = StreamKeyCreator(statuses),
) {
    
    override fun provideReactorPublisher(): Flowable<AmityStream> {
        return StreamReactorUseCase().execute(statuses).toRx2()
    }
    
    override fun forceRefresh(): Boolean = true
    
    override fun getFirstPageRequest(pageSize: Int): Single<EkoStreamQueryDto> {
        return getRequest(limit = pageSize)
    }
    
    override fun getFetchByTokenRequest(token: String): Single<EkoStreamQueryDto> {
        return getRequest(token = token)
    }
    
    override fun persistResponse(dto: EkoStreamQueryDto): Completable {
        return StreamListQueryPersister().persist(dto).toRx2()
    }
    
    override fun convertResponseToQueryToken(dto: EkoStreamQueryDto): QueryStreamQueryToken {
        return DynamicQueryStreamQueryToken(
                dynamicQueryStreamKeyCreator = StreamKeyCreator(statuses),
                next = dto.token.next,
                previous = dto.token?.previous,
                primaryKeys = dto.result.streams?.map { stream -> stream.streamId ?: ""} ?: emptyList()
        )
    }
    
    private fun getRequest(
            limit: Int? = null,
            token: String? = null
    ): Single<EkoStreamQueryDto> {
        return StreamRemoteDataStore().queryVideoStreaming(
            isLive = null,
            statuses = statuses,
            userPublicIds = null,
            sortBy = null,
            isDeleted = null,
            limit = limit,
            token = token
        ).toRx2()
    }
}
